# Curve Fitting RIVM scenario 2021-12-21
# Evert Mouw <post@evert.net>

using Plots
using CurveFit

using CSV
using DataFrames
using Dates

cd("/home/evert/Desktop/RIVM/")

#### RIVM

RIVM = DataFrame(CSV.File("RIVM_21dec21.csv"; header=false))
rename!(RIVM,:Column1 => :datum)
rename!(RIVM,:Column2 => :IC)

x = convert(Vector, RIVM[!,:datum])
FirstDate = x[1]
# Convert Days to Integers because curve_fit can't handle Dates
xint = Vector{Int}()
for i in 1:size(x,1)
    d = Dates.value(Dates.Day(x[i]-x[1]))
    push!(xint, d)
end

y = convert(Vector, RIVM[!,:IC])

fit = curve_fit(Polynomial, xint, y, 3)
cur = fit.(xint) 


d,c,b,a = fit
a = round(a, digits=3)
b = round(b, digits=3)
c = round(c, digits=3)
d = round(d, digits=3)
formula = "model fitted = $a x3 + $b x2 + $c x + $d"

plot(xint, [y cur],
    labels=["model RIVM" "model fitted"],
    ylabel="IC admissions", xlabel="days",
    title="RIVM scenario 2021-12-21")
annotate!(42, 80, text(formula, :brown, :left, 8))


####

empty!(x)
empty!(xint)
empty!(y)
empty!(cur)

#### LCPS

LCPS = DataFrame(CSV.File("LCPS_21dec21.csv"; header=false))
rename!(LCPS,:Column1 => :datum)
rename!(LCPS,:Column2 => :IC)

x = convert(Vector, LCPS[!,:datum])
#FirstDate = x[1]
# Convert Days to Integers because curve_fit can't handle Dates
#xint = Vector{Int}()
for i in 1:size(x,1)
    d = Dates.value(Dates.Day(x[i]-x[1]))
    push!(xint, d)
end

y = convert(Vector, LCPS[!,:IC])

fit = curve_fit(Polynomial, xint, y, 3)
cur = fit.(xint) 

d,c,b,a = fit
a = round(a, digits=3)
b = round(b, digits=3)
c = round(c, digits=3)
d = round(d, digits=3)
formula = "data fitted = $a x3 + $b x2 + $c x + $d"

plot!(xint, [y cur], labels=["data LCPS" "data fitted"],)
annotate!(42, 70, text(formula, :green, :left, 8))

####
annotate!(81, 140, text("Evert Mouw (2022-02-09)", :gray, :left, 6))
plot!(dpi=150)
savefig("scenario_21dec21")
