# Model estimates vs. reality:
# COVID-19 related IC admissions
# in The Netherlands
# Evert Mouw (2022-02-09)
#
# The model was adapted to Omicron's
# higher transmissibility,
# but _not_ to lower virulence...

using CSV
using DataFrames
using Statistics
using Plots

cd("/home/evert/Desktop/RIVM/")

LCPS = DataFrame(CSV.File("LCPS_gefilterd_covid-19-datafeed.csv"; header=false))
rename!(LCPS,:Column1 => :datum)
rename!(LCPS,:Column2 => :LCPS)

CSVlist = filter(endswith("_IC.csv"), readdir())
sort!(CSVlist)
i = 0
p = Plots.Plot{Plots.GRBackend}[]
for f in CSVlist
#f = "2021-11-03_IC.csv"
	global i += 1
	date = SubString(f,1:10)
	df = DataFrame(CSV.File(f; header=false))
	rename!(df,:Column1 => :datum)
	rename!(df,:Column2 => :RIVM)
	joined = rightjoin(LCPS, df, on=:datum)
	x = convert(Vector, joined[!,:datum])
	a = convert(Vector, joined[!,:LCPS])
	b = convert(Vector, joined[!,:RIVM])
	deltas = a - b
	datapoints = size(collect(skipmissing(deltas)),1)
	avgdelta = mean(skipmissing(deltas))
	avgdelta = round(avgdelta, digits=1)
	p_temp = plot(x, [a b], label = ["LCPS (real)" "RIVM (model)"], title = "$date, mean delta = $avgdelta ($datapoints observations)", lw = 2, dpi=150)
	push!(p, p_temp)
	# TODO StatsPlots won't compile :-(
	#p = @df plot(joined, :datum, [:LCPS :RIVM])
	savefig(p_temp, date)
end

garbageplot = plot(
	layout=grid(3,2),
	size = (1200,1200),
	p[1],
	p[2],
	p[3],
	p[4],
	p[5],
	p[6])
savefig(garbageplot, "garbageplot")

# ImageMagick command to combine the PNGs
# I could also have used native Julia but I prefer this
imagemagick = "montage -label %f -frame 6 -mattecolor '#FFFFBB' -geometry '1x1+0+0<' -tile 3x -bordercolor white *.png LCPS_RIVM.png"
